# -*- coding: UTF-8 -*-
# generated by lino.sphinxcontrib.help_text_builder
from django.utils.translation import gettext_lazy as _

help_texts = {
    'lino_cms.lib.cms.migrate.Migrator' : _("""The standard migrator for Lino Cms."""),
    'lino_cms.lib.cms.user_types.EndUser' : _("""An end user is somebody who uses our database, but won’t work
on it."""),
    'lino_cms.lib.cms.user_types.Admin' : _("""Can do everything."""),
}
